/**
 * @file
 * Behaviours for profiler wrapper.
 */

// Namespace.
const qToolsProfilerPreviewIframe = {
  'currentFold': '-',
  'requestId': null,
  'reportId': null,
  'loaded': null,
  'inspector': null,
  'requests': [],
  'reports': [],
  'wrapper': null,
  'header': null,
  'counter': null,
  'content': null
};

(function (Drupal, cookies, $) {
  const preview = qToolsProfilerPreview;
  const previewIframe = qToolsProfilerPreviewIframe;
  const observer = qToolsProfilerPreviewObserver;

  /**
   * On requests list update.
   */
  previewIframe.onUpdateRequests = function (requests) {
    previewIframe.counter.text(requests.length);
  };

  /**
   * On report select.
   */
  previewIframe.onSelectReport = function (reportId) {
    previewIframe.reportId = reportId;
    previewIframe.saveState();
  };

  /**
   * Message handlers.
   */
  previewIframe.handleMessage = {};

  /**
   * Handle minimize message.
   */
  preview.handleMessage['MINIMIZE'] = function(data, e) {
    previewIframe.minimize();
  };

  /**
   * Handle maximize message.
   */
  preview.handleMessage['MAXIMIZE'] = function(data, e) {
    previewIframe.maximize();
  };

  /**
   * Handle normalize message.
   */
  preview.handleMessage['NORMALIZE'] = function(data, e) {
    previewIframe.normalize();
  };

  /**
   * Creates visual elements.
   */
  previewIframe.createVisuals = function (context, settings) {
    // Build visuals.
    const counter = '<span id="qtools-profiler-preview-counter">0</span>';
    const header = '<div id="qtools-profiler-preview-header">' + counter + '</div>';
    const popup = '<div id="qtools-profiler-preview-popup"><ul></ul></div>';
    const content = '<iframe id="qtools-profiler-preview-content" />';
    const wrapper = '<div id="qtools-profiler-preview-wrapper" class="qtools-profiler-minimized"><div id="qtools-profiler-popup-wrapper">' + popup + header + '</div>' + content + '</div>';
    $('body').append(wrapper);

    // Shortcuts.
    previewIframe.wrapper = $('#qtools-profiler-preview-wrapper');
    previewIframe.content = $('#qtools-profiler-preview-content');
    previewIframe.header = $('#qtools-profiler-preview-header');
    previewIframe.popup = $('#qtools-profiler-preview-popup');
    previewIframe.popup_wrapper = $('#qtools-profiler-popup-wrapper');
    previewIframe.counter = $('#qtools-profiler-preview-counter');

    // Page cache status.
    const pageCacheStatus = $('#qtools-profiler-cache-status').attr('content') || "";
    if (pageCacheStatus.indexOf('HIT:') !== -1) {
      previewIframe.counter.css('color', 'LimeGreen');
    }
    else if (pageCacheStatus.indexOf('MISS:') !== -1) {
      previewIframe.counter.css('color', 'Orange');
    }
    else if (pageCacheStatus.indexOf('UNCACHEABLE:') !== -1) {
      previewIframe.counter.css('color', 'Firebrick');
    }

    if (pageCacheStatus.indexOf(':HIT') !== -1) {
      previewIframe.popup_wrapper.css('border', '4px solid LimeGreen');
    }
    else if (pageCacheStatus.indexOf(':MISS') !== -1) {
      previewIframe.popup_wrapper.css('border', '4px solid Orange');
    }
    else if (pageCacheStatus.indexOf(':UNCACHEABLE') !== -1) {
      previewIframe.popup_wrapper.css('border', '4px solid Firebrick');
    }

    const pageStatusColor = $('#qtools-profiler-page-status-color').attr('content') || "";
    if (pageStatusColor !== "") {
      previewIframe.header.css('background-color', pageStatusColor);
    }

    // Set up receiver.
    preview.iframeReceiver = previewIframe.content[0].contentWindow;

    // Attach anchor actions.
    previewIframe.header.click(function () {
      previewIframe.normalize();
    });
    previewIframe.popup_wrapper.mouseenter(function (event) {
      if (previewIframe.currentFold === '-') {
        previewIframe.popup.addClass('visible');
      }
    }).mouseleave(function (event) {
      previewIframe.popup.removeClass('visible');
    });

    // Add profiler actions.
    if (settings.qtools_profiler && settings.qtools_profiler.actions) {
      settings.qtools_profiler.actions.forEach(function (actionConfig) {
        if (actionConfig.type === "request" && actionConfig.config.method === 'location') {
          const link = '<li class="action-request-location" data-qtools-profiler-action="' + actionConfig.actionId + '"><a href="' + actionConfig.config.href + '" target="' + (actionConfig.config.target || '_self') + '">' + actionConfig.label + '</a><li>';
          previewIframe.popup.find('ul').append(link);
        }
      });
    }

    // Subscribe to observer.
    observer.subscribe({
      'onUpdateRequests': function (data) {
        previewIframe.onUpdateRequests(data.requests);
      },
      'onSelectReport': function (data) {
        previewIframe.onSelectReport(data.report);
      }
    });
  };

  /**
   * Normalize preview area size.
   */
  previewIframe.normalize = function() {
    previewIframe.setFold('');
  };

  /**
   * Minimize preview area size.
   */
  previewIframe.minimize = function() {
    previewIframe.setFold('-');
  };

  /**
   * Maximize preview area size.
   */
  previewIframe.maximize = function() {
    previewIframe.setFold('+');
  };

  /**
   * Sets new fold status.
   */
  previewIframe.setFold = function (newFold) {

    // Set iframe content if not yet.
    if (newFold !== '-' && previewIframe.content.attr('src') === undefined) {
      previewIframe.content.attr('src', observer.configuration.preview_app_url);
    }

    if (newFold === '+') {
      previewIframe.wrapper.addClass('qtools-profiler-maximized').removeClass('qtools-profiler-minimized');
      $('body').removeClass('qtools-profiler-open');
      if (preview.configuration.fullscreen === undefined) {
        preview.configuration.fullscreen = true;
      }
    }
    else if (newFold === '-') {
      previewIframe.wrapper.addClass('qtools-profiler-minimized').removeClass('qtools-profiler-maximized');
      $('body').removeClass('qtools-profiler-open');
    }
    else {
      newFold = '';
      previewIframe.wrapper.removeClass('qtools-profiler-minimized').removeClass('qtools-profiler-maximized');
      $('body').addClass('qtools-profiler-open');
    }
    previewIframe.currentFold = newFold;

    // Saves state.
    previewIframe.saveState();
  };

  /**
   * Sets selected report.
   */
  previewIframe.setReport = function (reportId) {
    previewIframe.reportId = reportId;
    preview.sendForceReport(reportId);
    previewIframe.saveState();
  };

  /**
   * Saves status of inspector.
   */
  previewIframe.saveState = function () {
    const options = { expires: 365, path: '/'};
    const state = {
      'fold': previewIframe.currentFold,
      'reportId': previewIframe.reportId
    };
    console.log('SAVE STATE', state);
    cookies.set('qtools-profiler-preview-iframe-state', JSON.stringify(state), options);
  };

  /**
   * Restore inspector state.
   */
  previewIframe.restoreState = function () {
    const cacheCookie = cookies.get('qtools_cache_profiler_active') || '';
    if (cacheCookie === '') {
      cookies.set('qtools_cache_profiler_active', 0, { expires: 365, path: '/'});
    }
    const stateCookie = cookies.get('qtools-profiler-preview-iframe-state') || '';
    if (stateCookie !== '') {
      const state = JSON.parse(stateCookie);
      previewIframe.setFold(state.fold);
      previewIframe.setReport(state.reportId);
    }
    else {
      previewIframe.minimize();
    }
  };

  /**
   * Handle pageLoad.
   */
  previewIframe.handlePageLoad = function (context, settings) {
    if (!previewIframe.loaded && settings.qtools_profiler) {
      previewIframe.loaded = true;

      setTimeout(function () {
        // Create visuals.
        previewIframe.createVisuals(context, settings);

        // Restore state.
        previewIframe.restoreState();
      }, 300);
    }
  };

  /**
   * Register behavior.
   */
  Drupal.behaviors.qToolsProfilerPreviewIframe = {
    attach: function (context, settings) {
      previewIframe.handlePageLoad(context, settings);
    }
  };

})(Drupal, window.Cookies, jQuery);
