/**
 * @file
 * Behaviours for profiler observer.
 */

(function () {

  // Register ajax command.
  if (qToolsProfilerPreviewObserver && Drupal.AjaxCommands) {
    var observer = qToolsProfilerPreviewObserver;

    /**
     * Add new command to populate summary for request.
     */
    Drupal.AjaxCommands.prototype.qtoolsProfilerPreviewSummary = function (ajax, response, status) {
      if (status === 'success') {
        var trackingId = response.trackingId;
        if (!trackingId || !observer.requests[trackingId]) {
          observer.pushRequest(response.name, response.requestId, response.type || null, response.summary, response.timestamp, !trackingId);
        }
        else {
          observer.updateRequest(trackingId, response.requestId, response.summary);
        }
      }
    };

    /**
     * Handle pageLoad.
     */
    observer.handlePageLoad = function (context, settings) {
      if (!observer.loaded && observer.configuration) {
        observer.loaded = true;

        // Load initial state.
        if (observer.configuration.stream) {
          observer.loadStream(observer.configuration.channel_id);
        }
        else if (observer.request_id) {
          // Request profiler info for main page.
          var ajax = Drupal.ajax({
            url: '/admin/config/development/qtools_profiler/preview_summary/' + observer.request_id + '/0'
          });
          ajax.execute();
        }
      }
    };

    /**
     * Register behavior.
     */
    Drupal.behaviors.qToolsProfilerPreviewObserver = {
      attach: function (context, settings) {
        observer.handlePageLoad(context, settings);
      }
    };

  }
})();