<?php

namespace Drupal\qtools_cache_profiler\Cache;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Symfony\Component\DependencyInjection\ContainerAwareInterface;
use Symfony\Component\DependencyInjection\ContainerAwareTrait;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Defines cache context if cache profiler enabled or not.
 */
class CacheProfilerActive implements CacheContextInterface, ContainerAwareInterface {

  // Cache contexts.
  const CACHE_CONTEXT_KEY = 'qtools_cache_profiler_active';

  use ContainerAwareTrait;

  /**
   * Request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * Constructs a new CustomerCanOrderContext service.
   */
  public function __construct(RequestStack $requestStack) {
    $this->requestStack = $requestStack;
  }

  /**
   * {@inheritdoc}
   */
  public static function getLabel() {
    return t("Cache profiling info added to HTML.");
  }

  /**
   * {@inheritdoc}
   */
  public function getContext() {
    $cookie_value = $this->requestStack->getMainRequest()->cookies->get(static::CACHE_CONTEXT_KEY, '');
    return !empty($cookie_value) ? '1' : '0';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata() {
    return new CacheableMetadata();
  }

}
