<?php

namespace Drupal\qtools_profiler\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\Site\Settings;
use Drupal\qtools_profiler\Cache\ProfilerPreviewAccessContext;

/**
 * Determines access to qtools_profiler previews.
 */
class ProfilerPreviewAccessCheck implements AccessInterface {

  /**
   * Drupal\Core\Session\AccountProxyInterface.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $accountProxy;

  /**
   * Constructor.
   */
  public function __construct(AccountProxyInterface $accountProxy) {
    $this->accountProxy = $accountProxy;
  }

  /**
   * Checks access to the qtools_profiler previews.
   */
  public function access(AccountInterface $account): AccessResultInterface {
    $preview_access = Settings::get('qtools_profiler_development_mode') ||
      $account->hasPermission('qtools_profiler.preview');
    $result = AccessResult::allowedIf($preview_access)->cachePerPermissions();
    $result->addCacheContexts([ProfilerPreviewAccessContext::CACHE_CONTEXT_KEY]);
    return $result;
  }

}
