<?php

namespace Drupal\qtools_profiler\Cache;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\qtools_profiler\Access\ProfilerPreviewAccessCheck;
use Symfony\Component\DependencyInjection\ContainerAwareInterface;
use Symfony\Component\DependencyInjection\ContainerAwareTrait;

/**
 * Defines cache context if cache profiler preview is accessible or not.
 */
class ProfilerPreviewAccessContext implements CacheContextInterface, ContainerAwareInterface {

  // Cache contexts.
  const CACHE_CONTEXT_KEY = 'qtools_profiler_preview_access';

  use ContainerAwareTrait;

  /**
   * Drupal\qtools_profiler\Access\ProfilerPreviewAccessCheck.
   *
   * @var \Drupal\qtools_profiler\Access\ProfilerPreviewAccessCheck
   */
  protected $profilerPreviewAccessCheck;

  /**
   * Constructs a new CustomerCanOrderContext service.
   */
  public function __construct(ProfilerPreviewAccessCheck $profilerPreviewAccessCheck) {
    $this->profilerPreviewAccessCheck = $profilerPreviewAccessCheck;
  }

  /**
   * {@inheritdoc}
   */
  public static function getLabel() {
    return t("Profiler preview accessible.");
  }

  /**
   * {@inheritdoc}
   */
  public function getContext() {
    /** @var \Drupal\Core\Session\AccountProxyInterface $current_user */
    $current_user = $this->container->get('current_user');
    $access = $this->profilerPreviewAccessCheck->access($current_user);
    return $access->isAllowed() ? '1' : '0';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata() {
    return new CacheableMetadata();
  }

}
