<?php

namespace Drupal\qtools_profiler\Controller;

use Drupal\Component\Utility\Crypt;
use Drupal\Component\Utility\Xss;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Flood\FloodInterface;
use Drupal\Core\Url;
use Drupal\qtools_common\Utility\TerminatedRedirectResponse;
use Drupal\user\Controller\UserController;
use Drupal\user\Form\UserPasswordResetForm;
use Drupal\user\UserDataInterface;
use Drupal\user\UserInterface;
use Drupal\user\UserStorageInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;

/**
 * Controller routines for user routes.
 *
 * @see UserController
 */
class UserLoginController extends UserController {

  /**
   * Validates user, hash, and timestamp; logs the user in if correct.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Returns a redirect to the user edit form if the information is correct.
   *   If the information is incorrect redirects to 'user.pass' route with a
   *   message for the user.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException
   *   If $uid is for a blocked user or invalid user ID.
   */
  public function userPassLogin($uid, $timestamp, $hash, Request $request) {
    // Call original login routine.
    // We don't want to accidentally introduce security issues so we don't
    // change drupal behavior in terms of login itself.
    $redirect = parent::resetPassLogin($uid, $timestamp, $hash, $request);

    // Determine operation result by checking 'pass_reset_<uid>' token.
    // In case of failure it will be empty.
    $token = $request->getSession()->get('pass_reset_' . $uid);
    if (empty($token)) {
      return $redirect;
    }

    // If we succeeded we don't want user to go and change password, instead
    // we redirect to HP (and remove token).
    $request->getSession()->remove('pass_reset_' . $uid);
    $this->messenger()->deleteAll();
    return new TerminatedRedirectResponse(Url::fromRoute('<front>')->setAbsolute()->toString());
  }

}
