import pageConnection from '../../utility/pageConnection'

export function updateReportSrc({ commit, state }) {
  let reportSrc = ''
  const selectedReport = state.reports.find((report) => report.reportId === state.selectedReport)
  const selectedRequest = state.selectedRequest
  if (selectedReport && selectedRequest && state.selectedRequest !== 0) {
    reportSrc = selectedReport.link.replace('{id}', selectedRequest)
  }
  commit('setReportSrc', reportSrc)
  console.log('setReportSrc', reportSrc)
}

export function selectReport({ commit, dispatch }, reportId) {
  pageConnection.onSelectReport(reportId);
  commit('selectReport', reportId)
  dispatch('updateReportSrc')
}

export function clearReport({ commit, dispatch }) {
  pageConnection.onSelectReport('');
  commit('selectReport', '')
  dispatch('updateReportSrc')
}

export function selectRequest({ commit, dispatch }, requestId) {
  pageConnection.onSelectRequest(requestId);
  commit('selectRequest', requestId)
  dispatch('updateReportSrc')
}

export function updateChannelStream({ commit, dispatch }) {
  pageConnection.updateChannelStream();
}

export function updateChannelHistory({ commit, dispatch }) {
  pageConnection.updateChannelHistory();
}

export function setFullscreen({ commit, dispatch }, fullscreen) {
  commit('setFullscreen', fullscreen)
  pageConnection.setFullscreen(fullscreen)
}

export function hideInspector({ commit, dispatch }) {
  commit('setFullscreen', false)
  pageConnection.hideInspector()
}

export function connectToPage ({ commit, state, dispatch }) {
  pageConnection.connect({
    CONFIGURATION: (params) => {
      commit('setConfiguration', params)
      if (params.fullscreen) {
        dispatch('setFullscreen', true)
      }
    },
    REPORTS_SET: (params) => {
      const reports = params.map((info) => {
        return {
          reportId: info[2],
          title: info[1],
          icon: info[3] || 'article',
          link: info[0]
        }
      });
      commit('setReports', reports)
      dispatch('updateReportSrc')
    },
    REQUESTS_SET: (params) => {
      const icons = {
        page: 'list_alt',
        xhr: 'keyboard_arrow_right',
        error: 'error_outline',
        redirect: 'shortcut',
        form: 'text_rotation_none',
        unknown: 'help_outline'
      }

      const requests = params.map((info) => {
        return {
          requestId: parseInt(info.requestId),
          label: info.name,
          path: info.path,
          type: info.type,
          icon: icons[info.type],
          timestamp: info.timestamp || null,
          summary: info.summary
        }
      })
      commit('setRequests', requests)
      if (state.selectedReport === '' && requests.length > 0) {
        commit('selectRequest', requests[0].requestId)
      }

      dispatch('updateReportSrc')
    },
    FORCE_REPORT: (params) => {
      commit('selectReport', params.report)
      dispatch('updateReportSrc')
    },
    ACTIONS_SET: (params) => {
      commit('setActions', params)
    }
  })
}
