function log (message, value, info) {
  console.log("iframe :: " + message, value, info)
}

class Connection {
  constructor() {
    this.id = 'inspector'
    this.mode = 'iframe'
    this.target = 'preview'
    this.connected = false
    this.handlers = {}
    this.commands = {
      CONNECT: 'CONNECT',
      SET_FOLD: 'SET_FOLD',
      MINIMIZE: 'MINIMIZE',
      MAXIMIZE: 'MAXIMIZE',
      NORMALIZE: 'NORMALIZE',
      CONFIGURATION: 'CONFIGURATION',
      UPDATE_CHANNEL_STREAM: 'UPDATE_CHANNEL_STREAM',
      UPDATE_CHANNEL_HISTORY: 'UPDATE_CHANNEL_HISTORY',
      SELECT_REPORT: 'SELECT_REPORT',
      SELECT_REQUEST: 'SELECT_REQUEST',
      REPORT_CONTENT_SET: 'REPORT_CONTENT_SET',
      REQUESTS_SET: 'REQUESTS_SET',
      RUN_ACTION: 'RUN_ACTION'
    }
  }

  sendMessage(command, params) {
    const message = {
      command,
      target: this.target,
      params: params || {}
    }

    window.parent.postMessage(message, '*')
    log('SEND', command, params)
  }

  processMessage(e) {
    if (e.data && e.data.target === this.id) {


      if (this.handlers[e.data.command]) {
        log('RECV ACCEPTED', e.data)
        this.handlers[e.data.command](e.data.params)
      }
      else {
        log('RECV NO HANDLER', e.data)
      }
    }
    else {
      // log('RECV IGNORED', e.data || null)
    }
  }

  connect(handlers) {
    if (this.connected) {
      log('ALREADY CONNECTED')
    }
    window.addEventListener('message', (e) => {
      this.processMessage(e)
    })
    this.sendMessage(this.commands.CONNECT, {
      'id': pageConnection.id,
      'mode': pageConnection.mode
    })

    this.handlers = handlers;
    this.connected = true
  }

  onSelectReport(reportId) {
    this.sendMessage(this.commands.SELECT_REPORT, {report: reportId})
  }

  onSelectRequest(requestId) {
    this.sendMessage(this.commands.SELECT_REQUEST, {request: requestId})
  }

  triggerAction(action, $event) {
    this.sendMessage(this.commands.RUN_ACTION, {
      actionId: action.actionId,
      value: $event.srcElement.value
    })
    console.log(action, $event.srcElement.value)
  }

  updateChannelStream() {
    this.sendMessage(this.commands.UPDATE_CHANNEL_STREAM)
  }

  updateChannelHistory() {
    this.sendMessage(this.commands.UPDATE_CHANNEL_HISTORY)
  }

  setFullscreen(fullscreen) {
    const command = fullscreen ? this.commands.MAXIMIZE : this.commands.NORMALIZE
    this.sendMessage(command)
  }

  hideInspector() {
    this.sendMessage(this.commands.MINIMIZE)
  }

}

const pageConnection = new Connection();

export default pageConnection
